Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(643)

Unified Diff: Source/core/rendering/RenderEmbeddedObject.cpp

Issue 931003002: Move and rename RenderPart to LayoutPart. (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Created 5 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/core/rendering/RenderEmbeddedObject.h ('k') | Source/core/rendering/RenderFrame.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/core/rendering/RenderEmbeddedObject.cpp
diff --git a/Source/core/rendering/RenderEmbeddedObject.cpp b/Source/core/rendering/RenderEmbeddedObject.cpp
index 0f4c69ef56019ccc24f5800f8e04aa33aed76d13..f6c09a12b30ee220288f38f0773538bd8a1578f8 100644
--- a/Source/core/rendering/RenderEmbeddedObject.cpp
+++ b/Source/core/rendering/RenderEmbeddedObject.cpp
@@ -53,7 +53,7 @@ static const float replacementTextRoundedRectRadius = 5;
static const float replacementTextTextOpacity = 0.55f;
RenderEmbeddedObject::RenderEmbeddedObject(Element* element)
- : RenderPart(element)
+ : LayoutPart(element)
, m_showsUnavailablePluginIndicator(false)
{
view()->frameView()->setIsVisuallyNonEmpty();
@@ -65,14 +65,14 @@ RenderEmbeddedObject::~RenderEmbeddedObject()
LayerType RenderEmbeddedObject::layerTypeRequired() const
{
// This can't just use RenderPart::layerTypeRequired, because LayerCompositor
// doesn't loop through RenderEmbeddedObjects the way it does frames in order
// to update the self painting bit on their Layer.
// Also, unlike iframes, embeds don't used the usesCompositing bit on RenderView
// in requiresAcceleratedCompositing.
if (requiresAcceleratedCompositing())
return NormalLayer;
- return RenderPart::layerTypeRequired();
+ return LayoutPart::layerTypeRequired();
}
static String unavailablePluginReplacementText(Node* node, RenderEmbeddedObject::PluginUnavailabilityReason pluginUnavailabilityReason)
@@ -109,7 +109,7 @@ void RenderEmbeddedObject::paintContents(const PaintInfo& paintInfo, const Layou
if (!isHTMLPlugInElement(element))
return;
- RenderPart::paintContents(paintInfo, paintOffset);
+ LayoutPart::paintContents(paintInfo, paintOffset);
}
void RenderEmbeddedObject::paint(const PaintInfo& paintInfo, const LayoutPoint& paintOffset)
@@ -119,7 +119,7 @@ void RenderEmbeddedObject::paint(const PaintInfo& paintInfo, const LayoutPoint&
return;
}
- RenderPart::paint(paintInfo, paintOffset);
+ LayoutPart::paint(paintInfo, paintOffset);
}
void RenderEmbeddedObject::paintReplaced(const PaintInfo& paintInfo, const LayoutPoint& paintOffset)
« no previous file with comments | « Source/core/rendering/RenderEmbeddedObject.h ('k') | Source/core/rendering/RenderFrame.h » ('j') | no next file with comments »
@@ -65,14 +65,14 @@ RenderEmbeddedObject::~RenderEmbeddedObject()
LayerType RenderEmbeddedObject::layerTypeRequired() const
{
- // This can't just use RenderPart::layerTypeRequired, because LayerCompositor
+ // This can't just use LayoutPart::layerTypeRequired, because LayerCompositor
// doesn't loop through RenderEmbeddedObjects the way it does frames in order
// to update the self painting bit on their Layer.

Powered by Google App Engine
This is Rietveld 408576698